# Dicebag

An infinite bag of dice.

```python3
>>> import dicebag
>>> dicebag.roll_d6()
5
>>> dicebag.roll_3d6()
9
>>> dicebag.roll_2d50()
43
```

# Caveats

This was written in a hurry, to show how clever I am. It should probably not be used in production.